from __future__ import with_statement
from pylab import *
import numpy as np
import sys, os


def set_discretization(discr_level):
    model = open ('nlpricing-subs.mod', 'w')
    with open('nlpricing.mod') as file:
        while True:
            line = file.readline()
            if line.startswith('param type_fine_level'):
                line = 'param type_fine_level = %s;' % discr_level
                model.write(line)  
            elif line == '':
                break
            else:
                model.write(line)
    model.close()


## General settings of the plot


def plot_settings():
    with open('eprofit.out', 'r') as file:
        tprofit = file.readline().rstrip('\n')
    with open('discretization.out', 'r') as file:
        discretization = file.readline().rstrip('\n')
    grid(True)
    xlabel(r'Types $\theta$')
    title(r'Discret: ' + discretization + '    ' + 'Profit: ' + tprofit)


## The plot functions


# Quantity
def plot_quantity():
    var = np.loadtxt('quantity.out')
    x = var[:,0]
    y = var[:,1]
    plot(x, y)

# Tariff
def plot_tariff():
    var = np.loadtxt('tariff.out')
    x = var[:,0]
    y = var[:,1]
    plot(x, y)

# Profits
def plot_profit():
    var = np.loadtxt('profit.out')
    x = var[:,0]
    y =var[:,1]
    plot(x, y)

# Utility
def plot_utility():
    var = np.loadtxt('utility_true.out')
    x = var[:,0]
    y = var[:,1]
    plot(x, y)


## Create plots

# Plots

def plot_all():
    plot_quantity()
    plot_tariff()
    plot_profit()
    plot_utility()
    # Legends
    legend((r'quantity', r'tariff', r'profit', r'utility'), shadow = True, loc=0)
    ltext = gca().get_legend().get_texts()

## Store plot

def saveplot(name=''):
    savefig('plot-d' + name + '.pdf')


## Define Main Command

def run(discr=[0.05]):
    for arg in discr:
        set_discretization(arg)
        os.system('ampl nlpricing-subs.run')
        plot_settings()
        plot_all()
        saveplot(name=str(arg))
        close()

## If ran from the command line ###

if __name__ == "__main__":
    inputs = [eval(arg) for arg in sys.argv[1:]]
    run(discr=inputs)
