

# Setup
# =======


# 1. Type Space
# --------------

param lbtypes := 2;   # Lower bound on types.
param ubtypes := 3;   # Upper bound on types.

# param type_fine_level := 0.037; # Good and fast! Bad shape for 'q'.
param type_fine_level := 0.005;

# The discretized type space. We have an interval in mind. Discretization
# specified in the data file. The number after 'by' is the unit of
# discretization.
set dTypes = lbtypes..ubtypes by type_fine_level;  
                                            
param p {dTypes};  # The common prior over types.
param n := card(dTypes);  # Number of points in the discretization of the type space.


# 2. Decision Variables
# ----------------------

param maxq := 0.51;
param maxt := 0.51;

var quantity {dTypes} >= 0, <= maxq;   # The quantity sold by the monopolist to
                                       # each type.

var tariff {dTypes} >= -maxt, <= maxt;   # The tariff paid by each type to the
                                         # monopolist.

# 3. Payoffs
# -------------

param b := 1;  # utility parameter.
param c := 6;  # cost parameter.

# The utility of a type 't1' agent of consuming the quantity specified for an
# agent of type 't2'.
#var value {t in dTypes, t1 in dTypes} = t * quantity[t] - b * t^2 * quantity[t]^2 * 0.5;

# The cost for the monopolist to supply quantity 'q[t1]' for an agent that
# reports type 't1'.
#var cost {t in dTypes} = c * quantity[t]^2 * 0.5;


# The Monopolist' Problem
# ========================


# 4. Objective
# -------------

# Using the midpoint rule for integration.
# maximize Profits:
#   ((ubtypes - lbtypes) / (2*n) ) * ( tariff[lbtypes] + 2 * sum {t in
#   dTypes: t > lbtypes} (tariff[t] - cost[t]));

maximize Profits:
  (1 / n) * sum {t in dTypes} (tariff[t] - c * quantity[t]^2 * 0.5);

# 5. Constraints
# ----------------

subject to

Individual_Rationality {t in dTypes}: 
  t * quantity[t] - b * t^2 * quantity[t]^2 * 0.5 - tariff[t] >= 0;

Incentive_Compatibility {t in dTypes, t1 in dTypes}:
  t * quantity[t] - b * t^2 * quantity[t]^2 * 0.5 - tariff[t] >= t * quantity[t1] - b * t^2 * quantity[t1]^2 * 0.5 - tariff[t1];


