

# Setup
# =======


# 1. Type Space
# --------------

param lbtypes := 2;   # Lower bound on types.
param mbtypes := 2.28;
param ubtypes := 3;   # Upper bound on types.

param type_fine_level := 0.04;
param type_extra_fine_level := 0.02;

# The discretized type space. We have an interval in mind. Discretization
# specified in the data file. The number after 'by' is the unit of
# discretization.
set dTypeslow = lbtypes..mbtypes by type_extra_fine_level;
set dTypeshigh = mbtypes+type_fine_level..ubtypes by type_fine_level;  
set dTypes = dTypeslow union dTypeshigh;

                                            
param p {dTypes};  # The common prior over types.
param n := card(dTypes);  # Number of points in the discretization of the type space.
param nlow := card(dTypeslow);
param nhigh := card(dTypeshigh);

# 2. Decision Variables
# ----------------------

param maxq := 0.51;
param maxt := 0.51;

var quantity {dTypes} >= 0, <= maxq;  # The quantity sold by the monopolist to each type.
var tariff {dTypes} >= -maxt, <= maxt;   # The tariff paid by each type to the
                                         # monopolist.

#set q := := 0.166666666666667	0.169901326537280	0.172943889315911	0.175802097067872	0.178483505662235	0.180995475113122	0.183111922829556	0.183111922829556	0.183111922829556	0.183111922829556	0.183111922829556	0.202431143777225	0.202431143777225	0.202431143777225	0.202431143777225	0.203106205972251	0.203665032022895	0.203991088028677	0.204119495578938	0.204078353181480	0.203890623461719	0.203575395597974	0.203148761681652	0.202624444363710	0.202431143777225	0.202431143777225	0.202431143777225	0.202431143777225	0.202431143777225	0.202431000000000	0.202431000000000	0.202431000000000	0.202431000000000;                                                                                  

# 3. Payoffs
# -------------

param b := 1;  # utility parameter.
param c := 6;  # cost parameter.

# The utility of a type 't1' agent of consuming the quantity specified for an
# agent of type 't2'.
var value {t in dTypes, t1 in dTypes} = t * quantity[t1] - b * t^2 * quantity[t1]^2 * 0.5;

# The cost for the monopolist to supply quantity 'q[t1]' for an agent that
# reports type 't1'.
var cost {t in dTypes} = c * quantity[t]^2 * 0.5;

## The revenue function
var revenue{t in dTypes}  = tariff[t] - cost[t];


# The Monopolist' Problem
# ========================


# 4. Objective
# -------------

# Using the midpoint rule for integration.
#maximize trProfits:
#  ((ubtypes - lbtypes) / (2*n) ) * ( tariff[lbtypes] + 2 * sum {t in
#  dTypes: t > lbtypes} (tariff[t] - cost[t]));

maximize Profits:
	(sum{t in dTypeslow}(tariff[t] - cost[t]) / nlow + sum{t in dTypeshigh}(tariff[t] - cost[t]) / nhigh) / 2;

# 5. Constraints
# ----------------

subject to

Individual_Rationality {t in dTypes}: 
  value[t, t] - tariff[t] >= 0;

Incentive_Compatibility {t in dTypes, t1 in dTypes}:
  value[t, t] - tariff[t] >= value[t, t1] - tariff[t1];

#Non-decreasing_Tariff {t in dTypes, t1 in dTypes}:
#  tariff[t] >= tariff[t1];


