%% This mfile plots the graphs of AMPL output for the robustness check part.
%% Models here follow the same indexing as nlp_uniform_robustness.run

clc
clear all
close all
%% Load data for benchmark case
data=load('quantity_uniform.out');
types_uniform=data(:,1);
quantity_uniform=data(:,2);
data=load('tariff_uniform.out');
tariff_uniform=data(:,2);
data=load('profits_uniform.out');
profits_uniform=data(:,2);
data=load('utilities_true_uniform.out');
utilities_true_uniform=data(:,2);

%% Load data for Model 2
data=load('quantity_uniform_uneven.out');
types_uniform_uneven=data(:,1);
quantity_uniform_uneven=data(:,2);
data=load('tariff_uniform_uneven.out');
tariff_uniform_uneven=data(:,2);
data=load('profits_uniform_uneven.out');
profits_uniform_uneven=data(:,2);
data=load('utilities_true_uniform_uneven.out');
utilities_true_uniform_uneven=data(:,2);

%% Load data for Model 3
data=load('quantity_uniform_uneven_right.out');
types_uniform_uneven_right=data(:,1);
quantity_uniform_uneven_right=data(:,2);
data=load('tariff_uniform_uneven_right.out');
tariff_uniform_uneven_right=data(:,2);
data=load('profits_uniform_uneven_right.out');
profits_uniform_uneven_right=data(:,2);
data=load('utilities_true_uniform_uneven_right.out');
utilities_true_uniform_uneven_right=data(:,2);

%% Load data for Model 4
data=load('quantity_uniform_uneven_uni.out');
types_uniform_uneven_uni=data(:,1);
quantity_uniform_uneven_uni=data(:,2);
data=load('tariff_uniform_uneven_uni.out');
tariff_uniform_uneven_uni=data(:,2);
data=load('profits_uniform_uneven_uni.out');
profits_uniform_uneven_uni=data(:,2);
data=load('utilities_true_uniform_uneven_uni.out');
utilities_true_uniform_uneven_uni=data(:,2);

%% Load data for Model 5
data=load('quantity_uniform_uneven_twin.out');
types_uniform_uneven_twin=data(:,1);
quantity_uniform_uneven_twin=data(:,2);
data=load('tariff_uniform_uneven_twin.out');
tariff_uniform_uneven_twin=data(:,2);
data=load('profits_uniform_uneven_twin.out');
profits_uniform_uneven_twin=data(:,2);
data=load('utilities_true_uniform_uneven_twin.out');
utilities_true_uniform_uneven_twin=data(:,2);


mtype1=2.28;
mtype2=2.72;


%% Plot the figures: quantities against types
figure(1)
set(gcf,'color',[1 1 1]); %Set the background color to white.

mv1=max([max(quantity_uniform) max(quantity_uniform_uneven) max(quantity_uniform_uneven_right) max(quantity_uniform_uneven_twin) max(quantity_uniform_uneven_uni)]);
mv2=min([min(quantity_uniform) min(quantity_uniform_uneven) min(quantity_uniform_uneven_right) min(quantity_uniform_uneven_twin) min(quantity_uniform_uneven_uni)]);
plot(types_uniform, quantity_uniform,'-','LineWidth',2)
hold all
plot(types_uniform_uneven, quantity_uniform_uneven,'-.','LineWidth',2)
hold all
plot(types_uniform_uneven_right, quantity_uniform_uneven_right,'--','LineWidth',2)
hold all
plot(types_uniform_uneven_twin, quantity_uniform_uneven_twin,'-.mo','LineWidth',2)
hold all
plot(types_uniform_uneven_uni, quantity_uniform_uneven_uni,'-.*','LineWidth',2)
hold off

legend('Uniform','Left','Right','Twin Peaks','Single Peak','Location','SouthEast');
box off
xlim([min(types_uniform) max(types_uniform)])
ylim([mv2 mv1])

%Place tick-marks on the x-axis.
set(gca,'XTick',[min(types_uniform) mtype1 mtype2 max(types_uniform)])
xtickstr=' | | |';
set(gca,'XTickLabel',xtickstr);

%Find the lower-left corner of the current axis. 
temp=get(gca,'position');
% Use this to create an in-line function that converts plot units to figure units.
funits = @(x) [temp(1)+temp(3)*(x(1)-min(types_uniform))/(max(types_uniform)-min(types_uniform)) temp(2)+temp(4)*(x(2))/(mv1) ];

%Axis labels.
loc1=funits([min(types_uniform) 0]);
loc2=funits([mtype1 0]);
loc3=funits([mtype2 0]);
loc4=funits([max(types_uniform) 0]);

annotation1 = annotation(...
  'textbox',...
  'Position',[loc1-[0.025 0] 0.05 0],...
  'LineStyle','none',...
  'FitHeightToText','off',...
  'FontSize',12,...
  'Interpreter','latex',...
  'String',{'$\underline{\theta}=2$'},...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');

annotation2 = annotation(...
    'textbox',...
    'Position',[loc2-[0.025 0] 0.05 0.0],...
    'LineStyle','none',...
    'FitHeightToText','off',...
    'FontSize',12,...
    'Interpreter','latex',...
    'String','$\theta_1=2.28$',...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');

annotation3 = annotation(...
    'textbox',...
    'Position',[loc3-[0.025 0] 0.05 0.0],...
    'LineStyle','none',...
    'FitHeightToText','off',...
    'FontSize',12,...
    'Interpreter','latex',...
    'String','$\theta_2=2.72$',...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');

annotation4 = annotation(...
    'textbox',...
    'Position',[loc4-[0.025 0] 0.05 0.0],...
    'LineStyle','none',...
    'FitHeightToText','off',...
    'FontSize',12,...
    'Interpreter','latex',...
    'String','$\overline{\theta}=3$',...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');

%% Plot the figures: tariffs against types
figure(2)
set(gcf,'color',[1 1 1]); %Set the background color to white.

mv1=max([max(tariff_uniform) max(tariff_uniform_uneven) max(tariff_uniform_uneven_right) max(tariff_uniform_uneven_twin) max(tariff_uniform_uneven_uni)]);
mv2=min([min(tariff_uniform) min(tariff_uniform_uneven) min(tariff_uniform_uneven_right) min(tariff_uniform_uneven_twin) min(tariff_uniform_uneven_uni)]);
plot(types_uniform, tariff_uniform,'-','LineWidth',2)
hold all
plot(types_uniform_uneven, tariff_uniform_uneven,'-.','LineWidth',2)
hold all
plot(types_uniform_uneven_right, tariff_uniform_uneven_right,'--','LineWidth',2)
hold all
plot(types_uniform_uneven_twin, tariff_uniform_uneven_twin,'-.mo','LineWidth',2)
hold all
plot(types_uniform_uneven_uni, tariff_uniform_uneven_uni,'-.*','LineWidth',2)
hold off

legend('Uniform','Left','Right','Twin Peaks','Single Peak','Location','SouthEast');
box off
xlim([min(types_uniform) max(types_uniform)])
ylim([mv2 mv1])

%Place tick-marks on the x-axis.
set(gca,'XTick',[min(types_uniform) mtype1 mtype2 max(types_uniform)])
xtickstr=' | | |';
set(gca,'XTickLabel',xtickstr);

%Find the lower-left corner of the current axis. 
temp=get(gca,'position');
% Use this to create an in-line function that converts plot units to figure units.
funits = @(x) [temp(1)+temp(3)*(x(1)-min(types_uniform))/(max(types_uniform)-min(types_uniform)) temp(2)+temp(4)*(x(2))/(mv1) ];

%Axis labels.
loc1=funits([min(types_uniform) 0]);
loc2=funits([mtype1 0]);
loc3=funits([mtype2 0]);
loc4=funits([max(types_uniform) 0]);

annotation1 = annotation(...
  'textbox',...
  'Position',[loc1-[0.025 0] 0.05 0],...
  'LineStyle','none',...
  'FitHeightToText','off',...
  'FontSize',12,...
  'Interpreter','latex',...
  'String',{'$\underline{\theta}=2$'},...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');

annotation2 = annotation(...
    'textbox',...
    'Position',[loc2-[0.025 0] 0.05 0.0],...
    'LineStyle','none',...
    'FitHeightToText','off',...
    'FontSize',12,...
    'Interpreter','latex',...
    'String','$\theta_1=2.28$',...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');

annotation3 = annotation(...
    'textbox',...
    'Position',[loc3-[0.025 0] 0.05 0.0],...
    'LineStyle','none',...
    'FitHeightToText','off',...
    'FontSize',12,...
    'Interpreter','latex',...
    'String','$\theta_2=2.72$',...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');

annotation4 = annotation(...
    'textbox',...
    'Position',[loc4-[0.025 0] 0.05 0.0],...
    'LineStyle','none',...
    'FitHeightToText','off',...
    'FontSize',12,...
    'Interpreter','latex',...
    'String','$\overline{\theta}=3$',...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');

%% Plot profits against types

figure(3)
set(gcf,'color',[1 1 1]); %Set the background color to white.

mv1=max([max(profits_uniform) max(profits_uniform_uneven) max(profits_uniform_uneven_right) max(profits_uniform_uneven_twin) max(profits_uniform_uneven_uni)]);
mv2=min([min(profits_uniform) min(profits_uniform_uneven) min(profits_uniform_uneven_right) min(profits_uniform_uneven_twin) min(profits_uniform_uneven_uni)]);
plot(types_uniform, profits_uniform,'-','LineWidth',2)
hold all
plot(types_uniform_uneven, profits_uniform_uneven,'-.','LineWidth',2)
hold all
plot(types_uniform_uneven_right, profits_uniform_uneven_right,'--','LineWidth',2)
hold all
plot(types_uniform_uneven_twin, profits_uniform_uneven_twin,'-.mo','LineWidth',2)
hold all
plot(types_uniform_uneven_uni, profits_uniform_uneven_uni,'-.*','LineWidth',2)
hold off

legend('Uniform','Left','Right','Twin Peaks','Single Peak','Location','SouthEast');
box off
xlim([min(types_uniform) max(types_uniform)])
ylim([mv2 mv1])

%Place tick-marks on the x-axis.
set(gca,'XTick',[min(types_uniform) mtype1 mtype2 max(types_uniform)])
xtickstr=' | | |';
set(gca,'XTickLabel',xtickstr);

%Find the lower-left corner of the current axis. 
temp=get(gca,'position');
% Use this to create an in-line function that converts plot units to figure units.
funits = @(x) [temp(1)+temp(3)*(x(1)-min(types_uniform))/(max(types_uniform)-min(types_uniform)) temp(2)+temp(4)*(x(2))/(mv1) ];

%Axis labels.
loc1=funits([min(types_uniform) 0]);
loc2=funits([mtype1 0]);
loc3=funits([mtype2 0]);
loc4=funits([max(types_uniform) 0]);

annotation1 = annotation(...
  'textbox',...
  'Position',[loc1-[0.025 0] 0.05 0],...
  'LineStyle','none',...
  'FitHeightToText','off',...
  'FontSize',12,...
  'Interpreter','latex',...
  'String',{'$\underline{\theta}=2$'},...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');

annotation2 = annotation(...
    'textbox',...
    'Position',[loc2-[0.025 0] 0.05 0.0],...
    'LineStyle','none',...
    'FitHeightToText','off',...
    'FontSize',12,...
    'Interpreter','latex',...
    'String','$\theta_1=2.28$',...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');

annotation3 = annotation(...
    'textbox',...
    'Position',[loc3-[0.025 0] 0.05 0.0],...
    'LineStyle','none',...
    'FitHeightToText','off',...
    'FontSize',12,...
    'Interpreter','latex',...
    'String','$\theta_2=2.72$',...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');

annotation4 = annotation(...
    'textbox',...
    'Position',[loc4-[0.025 0] 0.05 0.0],...
    'LineStyle','none',...
    'FitHeightToText','off',...
    'FontSize',12,...
    'Interpreter','latex',...
    'String','$\overline{\theta}=3$',...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');


%% Plot utilities against types

figure(4)
set(gcf,'color',[1 1 1]); %Set the background color to white.

mv1=max([max(utilities_true_uniform) max(utilities_true_uniform_uneven) max(utilities_true_uniform_uneven_right) max(utilities_true_uniform_uneven_twin) max(utilities_true_uniform_uneven_uni)]);
mv2=min([min(utilities_true_uniform) min(utilities_true_uniform_uneven) min(utilities_true_uniform_uneven_right) min(utilities_true_uniform_uneven_twin) min(utilities_true_uniform_uneven_uni)]);
plot(types_uniform, utilities_true_uniform,'-','LineWidth',2)
hold all
plot(types_uniform_uneven, utilities_true_uniform_uneven,'-.','LineWidth',2)
hold all
plot(types_uniform_uneven_right, utilities_true_uniform_uneven_right,'--','LineWidth',2)
hold all
plot(types_uniform_uneven_twin, utilities_true_uniform_uneven_twin,'-.mo','LineWidth',2)
hold all
plot(types_uniform_uneven_uni, utilities_true_uniform_uneven_uni,'-.*','LineWidth',2)
hold off

legend('Uniform','Left','Right','Twin Peaks','Single Peak','Location','SouthEast');
box off
xlim([min(types_uniform) max(types_uniform)])
ylim([mv2 mv1])

%Place tick-marks on the x-axis.
set(gca,'XTick',[min(types_uniform) mtype1 mtype2 max(types_uniform)])
xtickstr=' | | |';
set(gca,'XTickLabel',xtickstr);

%Find the lower-left corner of the current axis. 
temp=get(gca,'position');
% Use this to create an in-line function that converts plot units to figure units.
funits = @(x) [temp(1)+temp(3)*(x(1)-min(types_uniform))/(max(types_uniform)-min(types_uniform)) temp(2)+temp(4)*(x(2))/(mv1) ];

%Axis labels.
loc1=funits([min(types_uniform) 0]);
loc2=funits([mtype1 0]);
loc3=funits([mtype2 0]);
loc4=funits([max(types_uniform) 0]);

annotation1 = annotation(...
  'textbox',...
  'Position',[loc1-[0.025 0] 0.05 0],...
  'LineStyle','none',...
  'FitHeightToText','off',...
  'FontSize',12,...
  'Interpreter','latex',...
  'String',{'$\underline{\theta}=2$'},...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');

annotation2 = annotation(...
    'textbox',...
    'Position',[loc2-[0.025 0] 0.05 0.0],...
    'LineStyle','none',...
    'FitHeightToText','off',...
    'FontSize',12,...
    'Interpreter','latex',...
    'String','$\theta_1=2.28$',...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');

annotation3 = annotation(...
    'textbox',...
    'Position',[loc3-[0.025 0] 0.05 0.0],...
    'LineStyle','none',...
    'FitHeightToText','off',...
    'FontSize',12,...
    'Interpreter','latex',...
    'String','$\theta_2=2.72$',...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');

annotation4 = annotation(...
    'textbox',...
    'Position',[loc4-[0.025 0] 0.05 0.0],...
    'LineStyle','none',...
    'FitHeightToText','off',...
    'FontSize',12,...
    'Interpreter','latex',...
    'String','$\overline{\theta}=3$',...
    'HorizontalAlignment','center',...
    'VerticalAlignment','top');


% Print into pdf file
% set(gcf,'Position',[-3 5 1280 950],...
%     'PaperUnits','in','PaperSize',[17 11],'PaperPositionMode','manual','PaperPosition',[0 0 17 11]); %Set figure to screen size.
%print -dpdf -painters vstype_cross_experiments.pdf
