

# Setup
# =======


# 1. Type Space
# --------------

param lbtypes := 2;   # Lower bound on types.
param ubtypes := 3;   # Upper bound on types.

param type_fine_level := 0.15d0;

set Types = interval [lbtypes,ubtypes];
# The discretized type space. We have an interval in mind. Discretization
# specified in the data file. The number after 'by' is the unit of
# discretization.
set dTypes = lbtypes..ubtypes by type_fine_level;  
set bTypes = dTypes;
set tTypes = {dTypes,bTypes};


                                            
param p {dTypes};  # The common prior over types.
param n := card(tTypes);  # Number of points in the discretization of the type space.

#set locTypes{l in 1..n-1, i in 1..n} :=  dTypes [min(i-l,1)..max(i+l,n)];

set locTypes within dTypes;


#let {l in 1..n-1, i in 1..n} locTypes[l,i] := dTypes{min(i-l,1)..max(i+l,n)};



# 2. Decision Variables
# ----------------------

#param maxq := 0.51;
#param maxt := 0.51;

param maxq=3;
param maxt=3;

var q {dTypes,bTypes} >= 0, <= maxq;   # The quantity sold by the monopolist to each type.
#var tariff {dTypes} >= -maxt, <= maxt;   # The tariff paid by each type to the
                                         # monopolist.
var tariff {dTypes,bTypes} >= 0, <= maxt*2;


# 3. Payoffs
# -------------

param b := 1;  # utility parameter.
param c := 3;  # cost parameter.

# The utility of a type 't1' agent of consuming the quantity specified for an
# agent of type 't2'.
var value {td in dTypes, tb in bTypes, td1 in dTypes, tb1 in bTypes} = td * q[td1,tb1] - tb *q[td1,tb1]^2 * 0.5;
#var value {t in dTypes, t1 in dTypes} = t *sqrt(q[t1]);



# The cost for the monopolist to supply quantity 'q[t1]' for an agent that
# reports type 't1'.
var cost {td in dTypes, tb in bTypes} = c * q[tb,td]^2 * 0.5;
#var cost {t in dTypes} = c*q[t];

# The Monopolist' Problem
# ========================


# 4. Objective
# -------------

# Using the midpoint rule for integration.
maximize trProfits:
  sum {td in dTypes, tb in bTypes} (tariff[td,tb] - cost[td,tb]);

# 5. Constraints
# ----------------

subject to

Individual_Rationality {td in dTypes, tb in bTypes}: 
  value[td, tb, td, tb] - tariff[td,tb] >= 0;

Incentive_Compatibility {td in dTypes, tb in bTypes, td1 in dTypes, tb1 in bTypes}:
  value[td, tb, td, tb] - tariff[td,tb] >= value[td, tb, td1,tb1]-tariff[td1,tb1];



# Send Problem to Solver
# =======================

option presolve 0;

option solver knitroampl;
option knitro_options "feastol=1.0e-6 xtol=1.0e-6 opttol=1.0e-6 outlev=3  ms_enable=1 ms_maxtime_cpu=4500 ms_maxsolves=50 bar_feasible=0 newpoint=2 alg=3";
# 
solve;
display trProfits > knitro_results.txt;
display cost >> knitro_results.txt;
display value >> knitro_results.txt;
display q >> knitro_results.txt;
display tariff >> knitro_results.txt;

# option solver ipopt;
# solve;
# display trProfits > ipopt_results.txt;
# display cost >> ipopt_results.txt;
# display value >> ipopt_results.txt;
# display q >> ipopt_results.txt;
# display tariff >> ipopt_results.txt;

